@@ -625,13 +625,9 @@ typedef struct _xQueryFontReply {
     CARD16 sequenceNumber B16;
     CARD32 length B32;  /* definitely > 0, even if "nCharInfos" is 0 */
     xCharInfo minBounds; 
-#ifndef WORD64
     CARD32 walign1 B32;
-#endif
     xCharInfo maxBounds; 
-#ifndef WORD64
     CARD32 walign2 B32;
-#endif
     CARD16 minCharOrByte2 B16, maxCharOrByte2 B16;
     CARD16 defaultChar B16;
     CARD16 nFontProps B16;  /* followed by this many xFontProp structures */
@@ -674,13 +670,9 @@ typedef struct {
     CARD16 sequenceNumber B16;
     CARD32 length B32;  /* definitely > 0, even if "nameLength" is 0 */
     xCharInfo minBounds; 
-#ifndef WORD64
     CARD32 walign1 B32;
-#endif
     xCharInfo maxBounds; 
-#ifndef WORD64
     CARD32 walign2 B32;
-#endif
     CARD16 minCharOrByte2 B16, maxCharOrByte2 B16;
     CARD16 defaultChar B16;
     CARD16 nFontProps B16;  /* followed by this many xFontProp structures */
@@ -1447,12 +1439,7 @@ typedef struct {
     CARD16 length B16;
     Window destination B32;
     CARD32 eventMask B32;
-#ifdef WORD64
-    /* the structure should have been quad-aligned */
-    BYTE eventdata[SIZEOF(xEvent)];
-#else
     xEvent event;
-#endif /* WORD64 */
 } xSendEventReq;
 
 typedef struct {
